/*
    Copyright (C) 2005-2012  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _NNTPGRAB_AUTOMATION_H_
#define _NNTPGRAB_AUTOMATION_H_

#include "nntpgrab_utils.h"

typedef struct NNTPGrabAutoImport NNTPGrabAutoImport;
typedef struct NNTPGrabAutoImportClass NNTPGrabAutoImportClass;

typedef NGConfigOpts (*ConfigGetOptsFunc) (void *user_data);
typedef void (*ImportNZBFileFunc) (void *user_data, NNTPGrabNZB *nzbfile, const char *filename, char **errmsg);

NGType               nntpgrab_automation_auto_import_get_type(void);

/**
 * nntpgrab_automation_auto_import_new:
 * @config_get_opts_func:   The function which can be called to retrieve configuration settings
 * @import_nzb_file_func:   The function which can be called in order to import an NZB file
 * @user_data:              User provided callback data
 *
 * Create a new NNTPGrabAutoImport object
 */
NNTPGrabAutoImport  *nntpgrab_automation_auto_import_new(ConfigGetOptsFunc config_get_opts_func, ImportNZBFileFunc import_nzb_file_func, void *user_data);

/**
 * nntpgrab_automation_auto_import_destroy:
 * @auto_import:            The NNTPGrabAutoImport object which needs to be destroyed
 *
 * Destroy an NNTPGrabAutoImport object
 */
void                 nntpgrab_automation_auto_import_destroy(NNTPGrabAutoImport *auto_import);

/**
 * nntpgrab_automation_enable_auto_import:
 * @auto_import:                      An instance of the NNTPGrabAutoImport
 * @directory:                        The folder which needs to be monitored for NZB files
 * @errmsg:      (allow-none) (out):  Location to catch error messages. Can be NULL to ignore errors
 *
 * Enable monitoring of a specific folder
 * Only one folder can be monitored by one NNTPGrabAutoImport instance at a time
 *
 * Returns:         TRUE on success, FALSE on failure (errmsg will be set)
 */
ngboolean            nntpgrab_automation_enable_auto_import(NNTPGrabAutoImport *auto_import, const char *directory, char **errmsg);

/**
 * nntpgrab_automation_disable_auto_import:
 * @auto_import:            An instance of the NNTPGrabAutoImport
 *
 * Stop monitoring of a folder for new NZB files
 */
void                 nntpgrab_automation_disable_auto_import(NNTPGrabAutoImport *auto_import);

#endif /* _NNTPGRAB_AUTOMATION_H_ */

